@@ -171,6 +171,33 @@ class TestMain(object):
         assert parsed_args.with_solvent is False, \
             'Unexpected with_solvent settings were parsed'
 
+        # Test charges_from_file argument
+        parsed_args = parse_args(['BHP.pdb',
+                                  '--charges_from_file', 'BHP.mae'])
+
+        assert parsed_args.as_datalocal is False, \
+            'Unexpected as_datalocal settings were parsed'
+        assert parsed_args.charge_method == 'am1bcc', \
+            'Unexpected charge_method settings were parsed'
+        assert parsed_args.debug is False, \
+            'Unexpected debug settings were parsed'
+        assert parsed_args.forcefield == 'openff_unconstrained-1.3.0.offxml', \
+            'Unexpected forcefield settings were parsed'
+        assert parsed_args.include_terminal_rotamers is False, \
+            'Unexpected include_terminal_rotamers settings were parsed'
+        assert parsed_args.charges_from_file == 'BHP.mae', \
+            'Unexpected charges_from_file settings were parsed'
+        assert parsed_args.output is None, \
+            'Unexpected output settings were parsed'
+        assert parsed_args.pdb_file == 'BHP.pdb', \
+            'Unexpected pdb_file settings were parsed'
+        assert parsed_args.resolution == 30, \
+            'Unexpected resolution settings were parsed'
+        assert parsed_args.silent is False, \
+            'Unexpected silent settings were parsed'
+        assert parsed_args.with_solvent is False, \
+            'Unexpected with_solvent settings were parsed'
+
         # Test include_terminal_rotamers argument
         parsed_args = parse_args(['methane.pdb',
                                   '--include_terminal_rotamers'])
