@@ -11,6 +11,7 @@ __all__ = ["get_data_file_path",
            "unit_to_string",
            "quantity_to_string",
            "convert_all_quantities_to_string",
+           "parse_charges_from_mae",
            "Logger"
            ]
 
@@ -224,6 +225,77 @@ def convert_all_quantities_to_string(data_structure):
     return obj_to_return
 
 
+def parse_charges_from_mae(path, parameters):
+    """
+    It reads an external file containing the partial charges to assign to the
+    Molecule representation and updates the BaseParameterWrapper object
+    containing the molecule's parameters.
+
+    Parameters
+    ----------
+    path : str
+        Path to the MAE file with the charges information.
+    params : a BaseParameterWrapper object
+        The BaseParameterWrapper object to update the charges
+
+    Returns
+    -------
+    parameters : a BaseParameterWrapper object
+        The BaseParameterWrapper object with the updated charges.
+    """
+    import re
+
+    # Read external file containing the partial charges information
+    params_info, params_list = ([] for i in range(2))
+    copy = False
+    with open(path, 'r') as file:
+        for line in file.readlines():
+            if bool(re.match(r' m_atom\[(.*?)\] {', line)):
+                copy = True
+                type_data = 'info'
+            if ':::' in line:
+                type_data = 'params'
+            if '}' in line:
+                copy = False
+            if copy is True and type_data == 'info':
+                params_info.append(line)
+            if copy is True and type_data == 'params':
+                params_list.append(line)
+        params_info = [p.replace('\n', '').strip() for p in params_info[1:]]
+        params_list = [l.replace('"', '').split() for l in params_list[1:-1]]
+
+    # Get the index of the atom name and charge from the parameter's list
+    idx_charges, idx_atom_name = (None for i in range(2))
+    for idx, line in enumerate(params_info):
+        if 's_m_pdb_atom_name' in line:
+            idx_atom_name = idx
+        if 'r_m_charge1' in line:
+            idx_charges = idx
+    if idx_charges is None or idx_atom_name is None:
+        raise ValueError(
+            " {} does not contain charges information. ".format(path))
+
+    # Creates a charges by atom name dictionary
+    d = {}
+    for line in params_list:
+        d[line[idx_atom_name]] = line[idx_charges]
+
+    # Update the charges in BaseParameterWrapper object
+    new_charges_parameters = []
+    for atom_name in parameters['atom_names']:
+        atom_name = atom_name.replace('_', '')
+        if atom_name in d:
+            new_charges_parameters.append(unit.Quantity(
+                value=float(d.get(atom_name)),
+                unit=unit.elementary_charge))
+        else:
+            raise ValueError(
+                "Molecule atom name {} does not match with ".format(atom_name)
+                + "any external file atom name's.")
+    parameters['charges'] = new_charges_parameters
+    return parameters
+
+
 class Logger(object):
     """
     It contains all the required methods to handle logging messages.
